##  ESG Capability Fact Sheet Subtype
The ESG capability fact sheet subtype allows organizations to collect and manage sustainability data across their enterprise architecture layers. This enables data-driven decision-making and measurement of the impact of ESG initiatives. This helps ensure compliance with ESG regulations and standards by providing a framework for tracking and reporting sustainability metrics.
SAP LeanIX's flexible meta model allows for the easy [addition of new sections and fields](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the meta model to adjust it to your requirements.") to the ESG capability fact sheets, making it convenient to collect relevant data for new ESG projects. When undertaking a Twin transformation, relevant data may vary, but the ESG capability fact sheet serves as a starting point to identify necessary metrics. Users with Admin rights can effortlessly add new fields to relevant fact sheets to collect data once defined.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274186fa7a441014a81da8753d10c1fb_LowRes.png)
